"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getBrowseRouter = void 0;
const express_1 = require("express");
const http_errors_1 = require("http-errors");
const torrent_search_1 = require("../services/torrent-search");
const validation_1 = require("../helpers/validation");
function getBrowseRouter(_config, _logger) {
    return express_1.Router()
        .get('/browse/search', async (req, res) => {
        const query = validation_1.validateString(req.query.query, 'query');
        const category = req.query.category
            ? validation_1.validateString(req.query.category, 'category')
            : undefined;
        const provider = validation_1.validateString(req.query.provider, 'provider');
        if (!torrent_search_1.isProviderSupported(provider)) {
            throw new http_errors_1.BadRequest(`Provider ${provider} is not supported`);
        }
        return res.json(await torrent_search_1.search([provider], query, {
            category: category,
            limit: 50,
        }));
    })
        .get('/browse/providers', async (_req, res) => {
        return res.json(await torrent_search_1.getProvidersInfo());
    })
        .get('/browse/providers/:provider/magnet/:torrentId', async (req, res) => {
        const { provider, torrentId } = req.params;
        if (!torrent_search_1.isProviderSupported(provider)) {
            throw new http_errors_1.NotFound(`Provider ${provider} not found`);
        }
        const magnet = await torrent_search_1.providers[provider].getMagnet(torrentId);
        if (!magnet) {
            throw new http_errors_1.NotFound(`Torrent ${torrentId} not found`);
        }
        return res.json({
            magnet
        });
    });
}
exports.getBrowseRouter = getBrowseRouter;
