"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTorrentsRouter = void 0;
const express_1 = require("express");
const http_errors_1 = require("http-errors");
const validation_1 = require("../helpers/validation");
const helpers_1 = require("../helpers");
function getSteamUrl(torrent, file, encodeToken) {
    if (encodeToken) {
        return `/stream/${encodeURIComponent(helpers_1.signJwtToken({
            torrent,
            file,
        }, encodeToken))}`;
    }
    return `/stream/${encodeURIComponent(torrent)}?file=${encodeURIComponent(file)}`;
}
function torrentToJson(v, encodeToken) {
    return {
        name: v.name,
        infoHash: v.infoHash,
        downloadSpeed: v.getDownloadSpeed(),
        downloaded: v.getDownloaded(),
        link: v.link,
        started: v.created.getTime(),
        updated: v.updated.getTime(),
        files: v.files.map((f) => ({
            name: f.name,
            path: f.path,
            type: f.type,
            length: f.length,
            stream: getSteamUrl(v.link, f.path, encodeToken),
        })),
    };
}
function getTorrentsRouter(config, _logger, client) {
    const encodeToken = config.security.streamApi.key || config.security.apiKey;
    return express_1.Router()
        .post('/torrents', async (req, res) => {
        const link = validation_1.validateString(req.query.torrent, 'torrent');
        const torrent = await client.addTorrent(link);
        res.json(torrentToJson(torrent, encodeToken));
    })
        .get('/torrents', (_req, res) => {
        return res.json(client.getTorrents().map((v) => torrentToJson(v, encodeToken)));
    })
        .get('/torrents/:id', (req, res) => {
        const torrent = client.getTorrent(validation_1.validateString(req.params.id, 'id'));
        if (torrent) {
            return res.json(torrentToJson(torrent, encodeToken));
        }
        throw new http_errors_1.NotFound();
    });
}
exports.getTorrentsRouter = getTorrentsRouter;
