"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.configSchema = exports.frontendBuildPath = exports.readConfig = exports.isInHeroku = exports.isInGoogleAppEngine = exports.getEnv = void 0;
const fs_1 = require("fs");
const util_1 = require("util");
const path_1 = require("path");
const helpers_1 = require("./helpers");
const config_schema_json_1 = __importDefault(require("./config.schema.json"));
exports.configSchema = config_schema_json_1.default;
const validation_1 = require("./helpers/validation");
/**
 * Load enviroment variable using `EnvVariables` interface
 */
function getEnv(key, type = 'string') {
    const value = (process.env[key] || '').trim() || undefined;
    if (value) {
        if (type === 'json') {
            try {
                return JSON.parse(value);
            }
            catch (err) {
                throw new Error(`Failed to parse ${key} env variable: ${err}`);
            }
        }
        if (type === 'int') {
            return parseInt(value, 10) || undefined;
        }
        if (type === 'bool') {
            return (typeof value === 'string' && value.toLowerCase() === 'true');
        }
    }
    return value;
}
exports.getEnv = getEnv;
exports.isInGoogleAppEngine = process.env.GAE_APPLICATION ? true : false;
exports.isInHeroku = process.env._ ? process.env._.toLowerCase().includes('heroku') : false;
const defaultConfig = {
    host: getEnv('HOST') || '0.0.0.0',
    port: getEnv('PORT', 'int') || 3000,
    environment: getEnv('NODE_ENV', 'bool') === 'development' ? 'development' : 'production',
    trustProxy: getEnv('TRUST_PROXY') || exports.isInGoogleAppEngine || exports.isInHeroku,
    logging: {
        transports: [
            {
                type: 'console',
            },
        ],
        level: 'info',
    },
    torrents: {
        path: '/tmp/torrent-stream-server',
        ttl: 60 * 60,
        useDefaultTrackers: true,
        announce: [],
        urlList: [],
        peerAddresses: [],
    },
    security: {
        streamApi: {
            maxAge: '6h',
        },
        apiKey: getEnv('API_KEY') || undefined,
        frontendEnabled: true,
        apiEnabled: true,
    },
};
async function readConfig(path) {
    try {
        return validation_1.validateSchema(config_schema_json_1.default, helpers_1.merge(helpers_1.merge(defaultConfig, path ? JSON.parse(await util_1.promisify(fs_1.readFile)(path, { encoding: 'utf8' })) : {}), getEnv('CONFIG', 'json') || {}), {
            name: path || 'config',
        });
    }
    catch (err) {
        throw Error(`Configuration error: ${err}`);
    }
}
exports.readConfig = readConfig;
/**
 * Frontend package path to build directory
 */
exports.frontendBuildPath = path_1.resolve(__dirname, '../frontend/build');
